@@ -1507,7 +1507,7 @@ sub _handle_diff_provides {
 	}
 
 	if (@packages) {
-	    my $best = join('|', map { $_->id } @packages);
+	    my $best = join('|', sort { $a <=> $b } map { $_->id } @packages);
 	    $urpm->{debug_URPM}("promoting " . join(' ', _ids_to_fullnames($urpm, split('\|', $best))) . " because of conflict above") if $urpm->{debug_URPM};
 	    push @$properties, { required => $best, promote => $n, psel => $pkg };
 	} else {
@@ -1564,7 +1564,7 @@ sub _handle_conflict {
     }
 
     if (@packages) {
-	my $best = join('|', map { $_->id } @packages);
+	my $best = join('|', sort { $a <=> $b } map { $_->id } @packages);
 	$urpm->{debug_URPM}("promoting " . join('|', map { scalar $_->fullname } @packages) . " because of conflict above") if $urpm->{debug_URPM};
 	unshift @$properties, { required => $best, promote_conflicts => $reason };
     } else {
